==> hs-semigroups-0.8.tgz: lib/ghc/semigroups-0.8/register.sh <==
#!/bin/sh
echo 'name: semigroups
version: 0.8
id: semigroups-0.8-adc6a4a3783d643bd74aa3699e256d03

license: BSD3
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroups/
package-url:
description: Haskell 98 semigroups
             .
             In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.
category: Algebra, Data, Data Structures, Math
author: Edward A. Kmett
pkgpath: devel/hs-semigroups
exposed: True
exposed-modules: Data.Semigroup Data.List.NonEmpty Numeric.Natural
                 Numeric.Natural.Internal
hidden-modules:
import-dirs: /usr/local/lib/ghc/semigroups-0.8
library-dirs: /usr/local/lib/ghc/semigroups-0.8
hs-libraries: HSsemigroups-0.8
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
         containers-0.4.0.0-f1307d32d8f4b51a1487c01f0997b6d9
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-semigroups-0.8/html/semigroups.haddock
haddock-html: /usr/local/share/doc/hs-semigroups-0.8/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-semigroups-0.8.3.2p1.tgz: lib/ghc/semigroups-0.8.3.2/register.sh <==
#!/bin/sh
echo 'name: semigroups
version: 0.8.3.2
id: semigroups-0.8.3.2-08bd9e08e0f404cc4af18eab242e78de

license: BSD3
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroups/
package-url:
synopsis: Haskell 98 semigroups
description: Haskell 98 semigroups
             .
             In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.
category: Algebra, Data, Data Structures, Math
author: Edward A. Kmett
pkgpath: devel/hs-semigroups
exposed: True
exposed-modules: Data.Semigroup Data.List.NonEmpty Numeric.Natural
                 Numeric.Natural.Internal
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/semigroups-0.8.3.2
library-dirs: /usr/local/lib/ghc/semigroups-0.8.3.2
hs-libraries: HSsemigroups-0.8.3.2
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-semigroups-0.8.3.2/html/semigroups.haddock
haddock-html: /usr/local/share/doc/hs-semigroups-0.8.3.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
